pub struct GradCAM { /* private fields */ }Expand description
GradCAM (Gradient-weighted Class Activation Mapping)
GradCAM generates visual explanations for CNN decisions by using gradients flowing into the final convolutional layer to produce a coarse localization map highlighting important regions in the image.
Reference: Selvaraju et al., “Grad-CAM: Visual Explanations from Deep Networks via Gradient-based Localization”, ICCV 2017
Implementations
Sourceimpl GradCAM
impl GradCAM
Sourcepub fn new(target_layer_name: String, device: Arc<dyn Device>) -> Self
pub fn new(target_layer_name: String, device: Arc<dyn Device>) -> Self
Create a new GradCAM explainer
Arguments
target_layer_name- Name of the convolutional layer to use for visualization (typically the last conv layer before classification)device- Device to perform computations on
Sourcepub fn generate_heatmap(
&self,
model: &dyn Module,
input: &Tensor,
target_class: usize,
) -> Result<Tensor>
pub fn generate_heatmap( &self, model: &dyn Module, input: &Tensor, target_class: usize, ) -> Result<Tensor>
Sourcepub fn generate_gradcam_plus_plus(
&self,
model: &dyn Module,
input: &Tensor,
target_class: usize,
) -> Result<Tensor>
pub fn generate_gradcam_plus_plus( &self, model: &dyn Module, input: &Tensor, target_class: usize, ) -> Result<Tensor>
Generate GradCAM++ heatmap (improved version of GradCAM)
GradCAM++ provides better localization and works better for multiple instances of the same class in an image.