pub struct IntegratedGradients { /* private fields */ }Expand description
Integrated Gradients
Integrated Gradients is a method that attributes the prediction of a model to its input features by integrating gradients along a path from a baseline to the input.
Reference: Sundararajan et al., “Axiomatic Attribution for Deep Networks”, ICML 2017
Implementations